==> aws-android-sdk-translate-2.26.0-sources.jar: com/amazonaws/services/translate/model/transform/OutputDataConfigJsonUnmarshaller.java <==
/*
 * Copyright 2010-2020 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.translate.model.transform;

import com.amazonaws.services.translate.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;
import com.amazonaws.util.json.AwsJsonReader;

/**
 * JSON unmarshaller for POJO OutputDataConfig
 */
class OutputDataConfigJsonUnmarshaller implements
        Unmarshaller<OutputDataConfig, JsonUnmarshallerContext> {

    public OutputDataConfig unmarshall(JsonUnmarshallerContext context) throws Exception {
        AwsJsonReader reader = context.getReader();
        if (!reader.isContainer()) {
            reader.skipValue();
            return null;
        }
        OutputDataConfig outputDataConfig = new OutputDataConfig();
        reader.beginObject();
        while (reader.hasNext()) {
            String name = reader.nextName();
            if (name.equals("S3Uri")) {
                outputDataConfig.setS3Uri(StringJsonUnmarshaller.getInstance()
                        .unmarshall(context));
            } else {
                reader.skipValue();
            }
        }
        reader.endObject();
        return outputDataConfig;
    }

    private static OutputDataConfigJsonUnmarshaller instance;

    public static OutputDataConfigJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new OutputDataConfigJsonUnmarshaller();
        return instance;
    }
}

==> aws-android-sdk-translate-2.69.0-sources.jar: com/amazonaws/services/translate/model/transform/OutputDataConfigJsonUnmarshaller.java <==
/*
 * Copyright 2010-2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.translate.model.transform;

import com.amazonaws.services.translate.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;
import com.amazonaws.util.json.AwsJsonReader;

/**
 * JSON unmarshaller for POJO OutputDataConfig
 */
class OutputDataConfigJsonUnmarshaller implements
        Unmarshaller<OutputDataConfig, JsonUnmarshallerContext> {

    public OutputDataConfig unmarshall(JsonUnmarshallerContext context) throws Exception {
        AwsJsonReader reader = context.getReader();
        if (!reader.isContainer()) {
            reader.skipValue();
            return null;
        }
        OutputDataConfig outputDataConfig = new OutputDataConfig();
        reader.beginObject();
        while (reader.hasNext()) {
            String name = reader.nextName();
            if (name.equals("S3Uri")) {
                outputDataConfig.setS3Uri(StringJsonUnmarshaller.getInstance()
                        .unmarshall(context));
            } else if (name.equals("EncryptionKey")) {
                outputDataConfig.setEncryptionKey(EncryptionKeyJsonUnmarshaller.getInstance()
                        .unmarshall(context));
            } else {
                reader.skipValue();
            }
        }
        reader.endObject();
        return outputDataConfig;
    }

    private static OutputDataConfigJsonUnmarshaller instance;

    public static OutputDataConfigJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new OutputDataConfigJsonUnmarshaller();
        return instance;
    }
}
